# @ ${SOURCE_PATH}
CD ${EXAMPLES_PATH}/${PROJECT}/debian
cd ${EXAMPLES_PATH}/${PROJECT}/debian
FILES_INSTALL=$(echo *.install)
CD ${SOURCE_PATH}
cd ${SOURCE_PATH}
for f in 	${FILES_INSTALL} ; do
echo " \$ vim debian/$f"
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/$f debian/$f
L "cat debian/$f"
done

