# @ ${SOURCE_PATH}
echo " \$ mv debian/source/local-patch-header.ex debian/source/local-patch-header"
echo " \$ vim debian/source/local-patch-header"
echo " ... hack, hack, hack, ..."
# Let's set debian/source/local-patch-header non-interactively
rm -f debian/source/local-patch-header.ex
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/source/local-patch-header debian/source/local-patch-header
L "cat debian/source/local-patch-header"
