# directory structure (abs path)
#
# @ ${EXAMPLES_PATH}
# + - @ ${BUILD_PATH}
#     +- @ ${DSC_PATH}
#        +- @ ${SOURCE_PATH}

CD ${DSC_PATH} >/dev/null
cd ${DSC_PATH}
L "mkdir ${PROJECT}"
L "tree"
