# @ ${SOURCE_PATH}
echo " \$ rm debian/source/local-options.ex"
echo " \$ vim debian/source/local-options"
echo " ... hack, hack, hack, ..."
#echo "=== EXAMPLES_PATH = '${EXAMPLES_PATH}'"
#echo "=== PROJECT   = '${PROJECT}'"
#echo "=== TEST      = '${BUILD_PATH}'"
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/source/local-options debian/source/local-options
L "cat debian/source/local-options"
echo " \$ mv debian/source/local-patch-header.ex debian/source/local-patch-header"
echo " \$ vim debian/source/local-patch-header"
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/source/local-patch-header debian/source/local-patch-header
L "cat debian/source/local-patch-header"
