# @ ${SOURCE_PATH}
echo " ... hack, hack, hack, ...(dquilt or gbp-pq)"
mkdir -p debian/patches
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/patches/000-cmake-multiarch.patch debian/patches/000-cmake-multiarch.patch
echo "000-cmake-multiarch.patch" > debian/patches/series
L "cat debian/patches/series"
L "cat debian/patches/000-cmake-multiarch.patch"

